@@ -222,6 +222,16 @@ typedef union
     } ui32;
 } HSA_CAPABILITY;
 
+typedef union
+{
+    HSAuint32 Value;
+    struct
+    {
+        unsigned int PerSDMAQueueResetSupported : 1; // Indicates per-sdma queue reset supported
+        unsigned int Reserved : 31; // Reserved
+    } ui32;
+} HSA_CAPABILITY2;
+
 // Debug Properties and values
 // HSA runtime may expose a subset of the capabilities outlined to the applicati
 typedef union
@@ -281,6 +291,7 @@ typedef struct _HsaNodeProperties
                                        // units available on this node
 
     HSA_CAPABILITY  Capability;        // see above
+    HSA_CAPABILITY2  Capability2;      // see above
 
     HSAuint32       MaxWavesPerSIMD;   // This identifies the max. number of launched waves per SIMD.
                                        // If NumFComputeCores is 0, this value is ignored.
@@ -575,7 +586,8 @@ typedef struct _HsaMemFlags
             unsigned int GTTAccess:     1;  // default = 0; If 1: The caller indicates this memory will be mapped to GART for MES
 					    // KFD will allocate GTT memory with the Preferred_node set as gpu_id for GART mapping
             unsigned int Contiguous:	1; // Allocate contiguous VRAM
-            unsigned int Reserved:      9;
+            unsigned int ExecuteBlit:	1; // default = 0; If 1: The caller indicates that the memory is for blit kernel object.
+            unsigned int Reserved:      8;
 
         } ui32;
         HSAuint32 Value;
@@ -1501,6 +1513,11 @@ typedef union
 
 #pragma pack(pop, hsakmttypes_h)
 
+typedef enum _HsaAisFlags {
+    HSA_AIS_READ = 0x1,
+    HSA_AIS_WRITE= 0x2
+} HsaAisFlags;
+
 
 #ifdef __cplusplus
 }   //extern "C"
